What’s new in version 1.2.2
===========================
Version available since January 11th 2023


Bug fixed
---------

- Delete numerical noise in gradient, to avoid convergence issues on different computers.

Contributors
------------
Lucas Agobert
